Skip to contents

Formatting subtable data for analysis.

Usage

clean_subtable(df, drug_names, type)

Arguments

df

A dataframe of the subtable (repicate).

drug_names

A list where each element is the name of the corresponding drug.

type

An integer indicating the type of experiment: 2 for two-drug combinations, 3 for three-drug combinations.

Value

A list with two elements:

  • data_init: Numeric matrix/array of the response values

  • drug_doses: List of numeric vectors with the doses for each drug

Examples

NULL
#> NULL