Plot heatmap for drug combination data (data_init/data_bliss/data_diff).
plot_heatmap.RdPlot heatmap for drug combination data (data_init/data_bliss/data_diff).
Arguments
- data
A matrix or array containing initial, additivity or synergistic data.
- drug_names
A list where each element is the name of the corresponding drug.
- color
1 for initial/additivity data, 2 for synergistic data.
- title
Character string for the title of the heatmap.
- subtitle
Character string for the subtitle of the heatmap.